"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGuildStickers = void 0;
const mod_js_1 = require("../../mod.js");
/**
 * Returns an array of sticker objects for the given guild.
 *
 * @param bot The bot instance to use to make the request.
 * @param guildId The ID of the guild to get
 * @returns A collection of {@link Sticker} objects assorted by sticker ID.
 *
 * @remarks Includes user fields if the bot has the `MANAGE_EMOJIS_AND_STICKERS` permission.
 *
 * @see {@link https://discord.com/developers/docs/resources/sticker#list-guild-stickers}
 */
async function getGuildStickers(bot, guildId) {
    const results = await bot.rest.runMethod(bot.rest, "GET", bot.constants.routes.GUILD_STICKERS(guildId));
    return new mod_js_1.Collection(results.map((result) => {
        const pack = bot.transformers.sticker(bot, result);
        return [pack.id, pack];
    }));
}
exports.getGuildStickers = getGuildStickers;
