import { Bot } from "../../bot.js";
import { Sticker } from "../../transformers/sticker.js";
import { WithReason } from "../../types/discordeno.js";
import { AtLeastOne } from "../../types/shared.js";
/**
 * Edit the given sticker.
 *
 * @param bot The bot instance to use to make the request.
 * @param guildId The ID of the guild to get
 * @return A {@link Sticker}
 *
 * @remarks
 * Requires the `MANAGE_EMOJIS_AND_STICKERS` permission.
 * Fires a Guild Stickers Update Gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/sticker#modify-guild-sticker}
 */
export declare function editGuildSticker(bot: Bot, guildId: bigint, stickerId: bigint, options: AtLeastOne<EditGuildStickerOptions>): Promise<Sticker>;
export interface EditGuildStickerOptions extends WithReason {
    /** Name of the sticker (2-30 characters) */
    name?: string;
    /** Description of the sticker (empty or 2-100 characters) */
    description?: string | null;
    /** Autocomplete/suggestion tags for the sticker (max 200 characters) */
    tags?: string;
}
